==> nextcloud-23.0.9.tgz: nextcloud/apps/dashboard/l10n/zh_TW.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "儀表板",
    "Dashboard app" : "儀表板應用程式",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "開始您新的一天\n\nNextcloud 儀表板是您一天的起點，為您提供\n您即將到來的約會概覽、緊急電子郵件、聊天訊息、\n到來的工單、最新的推文以及更多！使用者可以新增\n他們喜愛的小工具與變更他們喜愛的背景。",
    "Customize" : "自訂",
    "Edit widgets" : "編輯小工具",
    "Get more widgets from the App Store" : "從應用程式商店取得更多小工具",
    "Change background image" : "變更背景圖片",
    "Weather service" : "天氣服務",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "為了保護您的隱私，Nextcloud 會代您請求氣象資料，因此天氣服務不會收到您的個人資訊。",
    "Weather data from Met.no" : "氣象資訊來自 Met.no",
    "geocoding with Nominatim" : "使用 Nominatim 來進行地理編碼",
    "elevation data from OpenTopoData" : "來自 OpenTopoData 的海拔資料",
    "Weather" : "天氣",
    "Status" : "狀態",
    "Good morning" : "早安",
    "Good morning, {name}" : "早安，{name}",
    "Good afternoon" : "午安",
    "Good afternoon, {name}" : "午安，{name}",
    "Good evening" : "晚安",
    "Good evening, {name}" : "晚安，{name}",
    "Hello" : "嗨",
    "Hello, {name}" : "嗨，{name}",
    "Pick from Files" : "從檔案選取",
    "Default image" : "預設影像",
    "Plain background" : "簡單背景",
    "Insert from {productName}" : "插入自 {productName}",
    "Show something" : "顯示一些東西",
    "Default images" : "預設圖片"
},
"nplurals=1; plural=0;");

==> nextcloud-24.0.10.tgz: nextcloud/apps/dashboard/l10n/zh_TW.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "儀表板",
    "Dashboard app" : "儀表板應用程式",
    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "開始您新的一天\n\nNextcloud 儀表板是您一天的起點，為您提供\n您即將到來的約會概覽、緊急電子郵件、聊天訊息、\n到來的工單、最新的推文以及更多！使用者可以新增\n他們喜愛的小工具與變更他們喜愛的背景。",
    "Customize" : "自訂",
    "Edit widgets" : "編輯小工具",
    "Get more widgets from the App Store" : "從應用程式商店取得更多小工具",
    "Weather service" : "天氣服務",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "為了保護您的隱私，Nextcloud 會代您請求氣象資料，因此天氣服務不會收到您的個人資訊。",
    "Weather data from Met.no" : "氣象資訊來自 Met.no",
    "geocoding with Nominatim" : "使用 Nominatim 來進行地理編碼",
    "elevation data from OpenTopoData" : "來自 OpenTopoData 的海拔資料",
    "Weather" : "天氣",
    "Status" : "狀態",
    "Good morning" : "早安",
    "Good morning, {name}" : "早安，{name}",
    "Good afternoon" : "午安",
    "Good afternoon, {name}" : "午安，{name}",
    "Good evening" : "晚安",
    "Good evening, {name}" : "晚安，{name}",
    "Hello" : "嗨",
    "Hello, {name}" : "嗨，{name}",
    "Change background image" : "變更背景圖片",
    "Pick from Files" : "從檔案選取",
    "Default images" : "預設圖片",
    "Plain background" : "簡單背景",
    "Insert from {productName}" : "插入自 {productName}"
},
"nplurals=1; plural=0;");
